ovariable from the OpasnetBase if availableddata_apply(ovariable, ddata_tidy = TRUE, force_ddata = FALSE, ...)ovariable with the ddata slot defined as page_id i.e. "Op_en1000"TRUE to run tidy on downloaded dataTRUE, dynamic data links are used even if the data slot of an ovariable is already definedovariable. (Re)defines the data slot if it is not already defined ands ddata is available.ovariable